# JSONAPI::SimpleClient

[![Gem](https://img.shields.io/gem/v/jsonapi-simple_client.svg?style=flat)](http://rubygems.org/gems/jsonapi-simple_client)
[![Depfu](https://badges.depfu.com/badges/7e9c019929f57d1b31eaf5a3de0412d1/overview.svg)](https://depfu.com/github/InspireNL/jsonapi-simple_client?project_id=5747)
[![Inline docs](http://inch-ci.org/github/InspireNL/jsonapi-simple_client.svg?branch=master&style=shields)](http://inch-ci.org/github/InspireNL/jsonapi-simple_client)
[![CircleCI](https://circleci.com/gh/InspireNL/jsonapi-simple_client.svg?style=svg)](https://circleci.com/gh/InspireNL/jsonapi-simple_client)
[![Maintainability](https://api.codeclimate.com/v1/badges/018b163368806b876765/maintainability)](https://codeclimate.com/github/InspireNL/jsonapi-simple_client/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/018b163368806b876765/test_coverage)](https://codeclimate.com/github/InspireNL/jsonapi-simple_client/test_coverage)

Client API to interact with a Server API that implements the JSON:API spec.

Links:

  - [API Docs](https://www.rubydoc.info/gems/jsonapi-simple_client)
  - [Contributing](https://github.com/InspireNL/jsonapi-simple_client/blob/master/CONTRIBUTING.md)
  - [Code of Conduct](https://github.com/InspireNL/jsonapi-simple_client/blob/master/CODE_OF_CONDUCT.md)

## Requirements

1. [Ruby 2.5.0](https://www.ruby-lang.org)

## Installation

To install, run:

```
gem install jsonapi-simple_client
```

Or add the following to your Gemfile:

```
gem "jsonapi-simple_client"
```

## Usage

Fetching resources:

```ruby
params = { include: "posts", sort: "title" }
headers = { authentication: "Bearer Token" }
response = JSONAPI::SimpleClient.fetch("http://api.example.com/users", headers, params)
response.class # => JSONAPI::Types::Success or JSONAPI::Types::Failure
```

Fetching relationships:

```ruby
response = JSONAPI::SimpleClient.fetch("http://api.example.com/users/1/relationships/posts")
response.class # => JSONAPI::Types::Success or JSONAPI::Types::Failure
```

Creating resources:

```ruby
payload = { data: { type: "users" } }
response = JSONAPI::SimpleClient.create("http://api.example.com/users", payload)
response.class # => JSONAPI::Types::Success, JSONAPI::Types::Failure or JSONAPI::Types::Document
```

Updating resources:

```ruby
payload = { data: { id: 1, type: "users" } }
response = JSONAPI::SimpleClient.update("http://api.example.com/users/1", payload)
response.class # => JSONAPI::Types::Success, JSONAPI::Types::Failure or JSONAPI::Types::Document
```

Updating relationships:

```ruby
payload = { data: { id: 1, type: "posts" } }
response = JSONAPI::SimpleClient.update("http://api.example.com/users/1/relationships/posts", payload)
response.class # => JSONAPI::Types::Success, JSONAPI::Types::Failure or JSONAPI::Types::Document
```

Deleting resources:

```ruby
response = JSONAPI::SimpleClient.delete("http://api.example.com/users/1")
response.class # => JSONAPI::Types::Info, JSONAPI::Types::Failure or JSONAPI::Types::Document
```

## Tests

To test, run:

```
bundle exec rspec spec/
```

## Versioning

Read [Semantic Versioning](https://semver.org) for details. Briefly, it means:

- Major (X.y.z) - Incremented for any backwards incompatible public API changes.
- Minor (x.Y.z) - Incremented for new, backwards compatible, public API enhancements/fixes.
- Patch (x.y.Z) - Incremented for small, backwards compatible, bug fixes.

## License

Copyright 2018 [Inspire Innovation BV](https://inspire.nl).
Read [LICENSE](LICENSE) for details.
